@@ -1,4 +1,6 @@
-envrtest <- function (set,env,numitr=1000,minval=0, replace=FALSE) 
+envrtest <- function (set,env,numitr=1000,minval=0, replace=FALSE,
+                plotit=TRUE, main=paste(deparse(substitute(set)),' on ',
+                deparse(substitute(env)))) 
 {
     prob <- 0
     if (!is.logical(set)) {
@@ -20,9 +22,13 @@ envrtest <- function (set,env,numitr=1000,minval=0, replace=FALSE)
         sdiff[i] <- null
     }
     prob <- min(1,(prob+1)/numitr)
-    plot(sort(sdiff),ylim=c(min(odiff,sdiff),max(sdiff)),ylab="Within-Set Difference")
-    abline(odiff,0,col=2)
-    text(0,max(sdiff),paste("p = ",format(prob,digits=3)),adj=0)
+    if (plotit) {
+        plot(sort(sdiff),ylim=c(min(odiff,sdiff),max(sdiff)),
+             ylab="Within-Set Difference",
+             main=main)
+        abline(odiff,0,col=2)
+        text(0,max(sdiff),paste("p = ",format(prob,digits=3)),adj=0)
+    }
     out <- list()
     out$diff <- odiff
     out$prob <- prob
