@@ -106,8 +106,13 @@ hilight.nmds <- function (ord, overlay, ax=1, ay=2, title="", cols=c(2,3,4,5,6,7
 {
     if (class(ord) != 'nmds')
        stop("You must pass an object of class nmds")
-    if (inherits(overlay,c('partana','pam','clustering')))
+    if (inherits(overlay,c('partana','pam','clustering'))) {
        overlay <- overlay$clustering
+       if (min(overlay)< 0 || (length(table(overlay)) != max(overlay))) {
+            cat('WARNING: renumbering clusters to consecutive integers\n')
+            overlay <- match(overlay,sort(unique(overlay)))
+       }
+    }
     if (is.logical(overlay) || is.factor(overlay))
         overlay <- as.numeric(overlay)
     plot(ord,ax=ax,ay=ay,type='n')
@@ -131,8 +136,13 @@ chullord.nmds<- function (ord, overlay, ax = 1, ay = 2, cols=c(2,3,4,5,6,7), lty
 {
     if (class(ord) != 'nmds')
         stop("You must pass an object of class nmds")
-    if (inherits(overlay,c('partana','pam','clustering')))
+    if (inherits(overlay,c('partana','pam','clustering'))) {
        overlay <- overlay$clustering
+       if (min(overlay)< 0 || (length(table(overlay)) != max(overlay))) {
+            cat('WARNING: renumbering clusters to consecutive integers\n')
+            overlay <- match(overlay,sort(unique(overlay)))
+       }
+    }
     else if (is.logical(overlay))
         overlay <- as.numeric(overlay)
     else if (is.factor(overlay))
@@ -160,8 +170,13 @@ density.nmds <- function (ord, overlay, ax = 1, ay = 2, cols = c(2, 3, 4, 5,
 {
     if (class(ord) != "nmds") 
         stop("You must pass an object of class nmds")
-    if (inherits(overlay, c("partana", "pam", "clustering"))) 
+    if (inherits(overlay, c("partana", "pam", "clustering"))) {
         overlay <- overlay$clustering
+       if (min(overlay)< 0 || (length(table(overlay)) != max(overlay))) {
+            cat('WARNING: renumbering clusters to consecutive integers\n')
+            overlay <- match(overlay,sort(unique(overlay)))
+       }
+    }
     else if (is.logical(overlay)) 
         overlay <- as.numeric(overlay)
     else if (is.factor(overlay)) 
